// #include <cstdio>
#include <ctime>

#include <string>

#include "hardware/pio.h"
#include "hardware/rtc.h"

#include "pico/cyw43_arch.h"
#include "pico/stdlib.h"
#include "pico/util/datetime.h"

#include "http_client.h"
#include "ntp_client.h"
#include "utils.h"
#include "ws2812.h"

using std::string;

#define WS2812_PIN 22

int main() {
    stdio_init_all();
    rtc_init();

#ifdef DEBUG
    printf("!!! DEBUG mode!!!\n\n");
#endif

    WS2812 led(WS2812_PIN);

    wifi_setup();

    NtpClient::setDateTime();
    HttpClient client;
    std::string csv("");
    for (int i = 1; i <= 10; i++) {
#ifdef DEBUG
        printf("Attempt %d for retrieving data.\n", i);
#endif
        csv = client.retrieveWasteDatesAsCsv();
        if (csv.length() > 0) {
#ifdef DEBUG
            printf("Data received!\n");
#endif
            break;
        }
    }

    if (csv.length() == 0) {
#ifdef DEBUG
        printf("Error getting data. Exiting!");
#endif
        cyw43_arch_deinit();
        return 1;
    }

    char datetime_buf[256];
    char *datetime_str = &datetime_buf[0];
    datetime_t dt;

    auto dates = parseCsv(csv);
#ifdef DEBUG
    printf("Number of Dates: %d\n", dates.size());
#endif
    while (true) {
        rtc_get_datetime(&dt);

        datetime_to_str(datetime_str, sizeof(datetime_buf), &dt);
        // printf("DateTime: %s\n", datetime_str);
        led.switchColor(Color::OFF);
        sleep_ms(5000);
    }

    cyw43_arch_deinit();
}
